// ASPBUGFILTER.CPP - Implementation file for your Internet Server
//
// by Christoph Wille, 2. July 1998, comments always welcome
// Christoph.Wille@softwing.com, AUSTRIA

// fixes the "::$DATA" problem - see OnUrlMap for the implementation
// hint: this is a modified version of the "." bug filter



#define SERVICE_NAME	 (_T("DDATAFIX"))
#include "msgs.h"

#include <afx.h>
#include <afxwin.h>
#include <afxisapi.h>
#include "resource.h"
#include "aspbugfilter.h"


///////////////////////////////////////////////////////////////////////
// The one and only CAspbugfilterFilter object

CAspbugfilterFilter theFilter;


///////////////////////////////////////////////////////////////////////
// CAspbugfilterFilter implementation

CAspbugfilterFilter::CAspbugfilterFilter()
{
	m_hEventSource = NULL;
}

CAspbugfilterFilter::~CAspbugfilterFilter()
{
	if (NULL != m_hEventSource) 
		DeregisterEventSource(m_hEventSource);
}

BOOL CAspbugfilterFilter::GetFilterVersion(PHTTP_FILTER_VERSION pVer)
{
	// Call default implementation for initialization
	CHttpFilter::GetFilterVersion(pVer);

	// Clear the flags set by base class
	pVer->dwFlags &= ~SF_NOTIFY_ORDER_MASK;

	// Set the flags we are interested in
	// one interesting flaw was in here: it ignored secure connections
	// fixed that: CW 22.02.1997, 9am
	pVer->dwFlags |= SF_NOTIFY_ORDER_HIGH | SF_NOTIFY_NONSECURE_PORT | SF_NOTIFY_URL_MAP | SF_NOTIFY_SECURE_PORT;

	// Load description string
	TCHAR sz[SF_MAX_FILTER_DESC_LEN+1];
	ISAPIVERIFY(::LoadString(AfxGetResourceHandle(),
			IDS_FILTER, sz, SF_MAX_FILTER_DESC_LEN));
	_tcscpy(pVer->lpszFilterDesc, sz);
	
	// log the start event
	LogEvent(EVENTLOG_INFORMATION_TYPE, EVMSG_INSTALLED, SERVICE_NAME);

	
	return TRUE;
}

DWORD CAspbugfilterFilter::OnUrlMap(CHttpFilterContext* pCtxt,
	PHTTP_FILTER_URL_MAP pMapInfo)
{
	LPCTSTR lpsz = pMapInfo->pszURL;

	CString strURL = lpsz;
	strURL.MakeUpper();		// actually not necessary, but helps to detect "silly" hackers

	// check if we find an error, if not continue
	if (-1 == strURL.Find("::$DATA"))
	{
		return SF_STATUS_REQ_NEXT_NOTIFICATION;
	}

	// log an event for the admin...
	LogEvent(EVENTLOG_WARNING_TYPE, EVMSG_REQ_FILE, SERVICE_NAME, strURL);	
	
	// immediately close connection.
	return SF_STATUS_REQ_FINISHED;
}

// this code is taken from MSDN
// "Creating a Simple Windows NT Service in C++"
// by Nigel Thompson
void CAspbugfilterFilter::LogEvent(WORD wType, DWORD dwID,
                          const char* pszS1,
                          const char* pszS2,
                          const char* pszS3)
{
    const char* ps[3];
    ps[0] = pszS1;
    ps[1] = pszS2;
    ps[2] = pszS3;

    int iStr = 0;
    for (int i = 0; i < 3; i++) {
        if (ps[i] != NULL) iStr++;
    }

    // Check to see if the event source has been registered,
    // and if not then register it now.
    if (!m_hEventSource) {
        m_hEventSource = ::RegisterEventSource(NULL,            // local machine
                                               SERVICE_NAME); // source name
    }

    if (m_hEventSource) {
        ::ReportEvent(m_hEventSource,
                      wType,
                      0,
                      dwID,
                      NULL,   // sid
                      iStr,
                      0,
                      ps,
                      NULL);
    }
}



///////////////////////////////////////////////////////////////////////
// If your extension will not use MFC, you'll need this code to make
// sure the extension objects can find the resource handle for the
// module.  If you convert your extension to not be dependent on MFC,
// remove the comments arounn the following AfxGetResourceHandle()
// and DllMain() functions, as well as the g_hInstance global.

/****

static HINSTANCE g_hInstance;

HINSTANCE AFXISAPI AfxGetResourceHandle()
{
	return g_hInstance;
}

BOOL WINAPI DllMain(HINSTANCE hInst, ULONG ulReason,
					LPVOID lpReserved)
{
	if (ulReason == DLL_PROCESS_ATTACH)
	{
		g_hInstance = hInst;
	}

	return TRUE;
}

****/
